@@ -7,9 +7,9 @@
 
     Last commit info:
     ~~~~~~~~~~~~~~~~~
-    $LastChangedDate: 2010-04-04 19:49:21 +0200 (So, 04. Apr 2010) $
-    $Rev: 42 $
-    $Author: google.groups@jensdiemer.de $
+    $LastChangedDate$
+    $Rev$
+    $Author$
 
     :copyleft: 2008-2009 by python-creole team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE.txt for more details.
