@@ -1,16 +1,13 @@
 # -*- coding: utf-8 -*-
 
 """
-    unitest utils
-    ~~~~~~~~~~~~~
-
-    Last commit info:
+    html2creole tests
     ~~~~~~~~~~~~~~~~~
-    $LastChangedDate: 2009-05-16 11:21:38 +0200 (Sa, 16 Mai 2009) $
-    $Rev: 36 $
-    $Author: google.groups@jensdiemer.de $
+    
+    special html to creole convert tests, witch can't tests in "cross compare"
+    
 
-    :copyleft: 2008-2009 by python-creole team, see AUTHORS for more details.
+    :copyleft: 2008-2010 by python-creole team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE.txt for more details.
 """
 
@@ -48,10 +45,12 @@ class TestHtml2CreoleMarkup(BaseCreoleTest):
             **Bold text**
             **Big text**
             //em tag//
+            //italic//
         """, """
             <p><b>Bold text</b><br />
             <big>Big text</big><br />
-            <em>em tag</em></p>
+            <em>em tag</em><br />
+            <i>italic</i></p>
         """)
 
     def test_raise_unknown_node(self):
@@ -163,7 +162,7 @@ class TestHtml2CreoleMarkup(BaseCreoleTest):
             </table>
             <p>end</p>
         """)
-        
+
     def test_p_table(self):
         """ strip <p> tags in table cells """
         self.assertCreole(r"""
@@ -177,9 +176,45 @@ class TestHtml2CreoleMarkup(BaseCreoleTest):
             </table>
         """)
 
+    def test_image(self):
+        """ test image tag with different alt/title attribute """
+        self.assertCreole(r"""
+            {{foobar1.jpg|foobar1.jpg}}
+            {{/foobar2.jpg|foobar2.jpg}}
+            {{/path1/path2/foobar3.jpg|foobar3.jpg}}
+            {{/foobar4.jpg|It's foobar 4}}
+            {{/foobar5.jpg|It's foobar 5}}
+            {{/foobar6.jpg|a long picture title}}
+        """, """
+            <p><img src="foobar1.jpg" /><br />
+            <img src="/foobar2.jpg" /><br />
+            <img src="/path1/path2/foobar3.jpg" /><br />
+            <img src="/foobar4.jpg" alt="It's foobar 4" /><br />
+            <img src="/foobar5.jpg" title="It's foobar 5" /><br />
+            <img src="/foobar6.jpg" alt="short name" title="a long picture title" /></p>
+        """)
+
+    def test_non_closed_br(self):
+        self.assertCreole(r"""
+            one
+            two
+        """, """
+            <p>one<br>
+            two</p>
+        """)
+
+    def test_explicit_closed_br(self):
+        self.assertCreole(r"""
+            one
+            two
+        """, """
+            <p>one<br></br>
+            two</p>
+        """)
+
     #--------------------------------------------------------------------------
     # TODOs:
-    
+
     def test_format_in_a_text(self):
         """ http://code.google.com/p/python-creole/issues/detail?id=4 """
         self.assertCreole(r"""
@@ -367,4 +402,4 @@ if __name__ == '__main__':
     unittest.main()
 #if __name__ == '__main__':
 #    suite = unittest.TestLoader().loadTestsFromTestCase(TestHtml2Creole)
-#    unittest.TextTestRunner().run(suite)
\ No newline at end of file
+#    unittest.TextTestRunner().run(suite)
